<?xml version="1.0"?> 
<xsl:stylesheet
        version="2.0" 
        xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
        xmlns:XSL="http://www.pubmedcentral.gov/XSL"
        xmlns:xlink="http://www.w3.org/1999/xlink" 
        xmlns:redirect="http://www.pubmedcentral.gov/redirect"
        xmlns="http://www.w3.org/1999/xhtml" 
        exclude-result-prefixes="XSL xlink redirect">


	<xsl:template name="get_mimetype">
		<xsl:param name="source"/>
		<xsl:variable name="normsource" select="lower-case($source)"/>
		<xsl:choose>
			<xsl:when test="contains($normsource,'/')">
				<xsl:value-of select="$normsource"/>
			</xsl:when>
			<!-- IMAGE -->
			<xsl:when test="contains($normsource,'.bmp') or
							contains($normsource,'.gif') or
							contains($normsource,'.jpg') or
							contains($normsource,'.jpeg') or
							contains($normsource,'svg') or
							contains($normsource,'.tif') or
							contains($normsource,'.tiff') or
							contains($normsource,'.png')">

				<!-- write output -->
				<xsl:value-of select="'image'"/><xsl:text>/</xsl:text>
				
				<xsl:call-template name="image-subtype">
					<xsl:with-param name="source" select="$normsource"/>
					</xsl:call-template>	
				</xsl:when>
			<!-- APPLICATION -->
			<xsl:when test="contains($normsource,'bin') or 
							    contains($normsource,'dcr') or
							    contains($normsource,'dir') or
							    contains($normsource,'doc') or
							    contains($normsource,'dxr') or
							    contains($normsource,'exe') or
							    contains($normsource,'gz') or
							    contains($normsource,'hlp') or
							    contains($normsource,'hqz') or
							    contains($normsource,'jar') or
							    contains($normsource,'mdb') or
							    contains($normsource,'ncx') or
							    contains($normsource,'pdf') or
							    contains($normsource,'ppt') or
							    contains($normsource,'eps') or
							    contains($normsource,'ps') or
							    contains($normsource,'rtf') or
							    contains($normsource,'swf') or
							    contains($normsource,'tar') or
							    contains($normsource,'wpd') or
							    contains($normsource,'xls') or
							    contains($normsource,'zip')">
				
				<!-- write output -->
					<xsl:value-of select="'application'"/><xsl:text>/</xsl:text>
					
				<xsl:call-template name="application-subtype">
					<xsl:with-param name="source" select="$normsource"/>
					</xsl:call-template>	
				</xsl:when>
			<!-- AUDIO -->
			<xsl:when test="contains($normsource,'au') or
							    contains($normsource,'midi') or
								 contains($normsource,'mp3') or
								 contains($normsource,'ra') or
								 contains($normsource,'wav')">
				
				<!-- write output -->
				<xsl:value-of select="'audio'"/><xsl:text>/</xsl:text>
				
				<xsl:call-template name="audio-subtype">
					<xsl:with-param name="source" select="$normsource"/>
					</xsl:call-template>	
				</xsl:when>
			<!-- VIDEO -->
			<xsl:when test="contains($normsource,'asf') or
							    contains($normsource,'avi') or
								 contains($normsource,'mov') or
								 contains($normsource,'mp4') or
								 contains($normsource,'mpeg') or
								 contains($normsource,'mpg') or
								 contains($normsource,'rm') or
								 contains($normsource,'rv') or
								 contains($normsource,'wmv')">
				<!-- write output -->
				<xsl:value-of select="'video'"/>
				<xsl:text>/</xsl:text>
				
				<xsl:call-template name="video-subtype">
					<xsl:with-param name="source" select="$normsource"/>
					</xsl:call-template>	
				</xsl:when>
			<!-- TEXT -->
			<xsl:otherwise>
				<xsl:value-of select="'text/'"/>
				<xsl:call-template name="text-subtype">
					<xsl:with-param name="source" select="$normsource"/>
					</xsl:call-template>	
				</xsl:otherwise>
			</xsl:choose>
		</xsl:template>


	<xsl:template name="image-subtype">
		<xsl:param name="source"/>
		<xsl:choose>
			<xsl:when test="contains($source,'bmp')">bmp</xsl:when>
			<xsl:when test="contains($source,'gif')">gif</xsl:when>
			<xsl:when test="contains($source,'jpg')">jpeg</xsl:when>
			<xsl:when test="contains($source,'jpeg')">jpeg</xsl:when>
			<xsl:when test="contains($source,'png')">png</xsl:when>
			<xsl:when test="contains($source,'.svg')">svg+xml</xsl:when>
			<xsl:when test="contains($source,'tif')">tiff</xsl:when>
			<xsl:when test="contains($source,'tiff')">tiff</xsl:when>
			</xsl:choose>
		</xsl:template>


	<xsl:template name="application-subtype">
		<xsl:param name="source"/>
			<xsl:choose>
				<xsl:when test="contains($source,'bin')">octet-stream</xsl:when>
				<xsl:when test="contains($source,'doc')">msword</xsl:when>
				<xsl:when test="contains($source,'dir') or
								contains($source,'dxr') or
								contains($source,'dcr')">x-director</xsl:when>
				<xsl:when test="contains($source,'exe')">x-msdownload</xsl:when>
				<xsl:when test="contains($source,'gz')">x-zip-compressed</xsl:when>
				<xsl:when test="contains($source,'hlp')">winhlp32</xsl:when>
				<xsl:when test="contains($source,'hqz')">mac-binhex40</xsl:when>
				<xsl:when test="contains($source,'jar')">java-archive</xsl:when>
				<xsl:when test="contains($source,'mdb')">vnd.ms-access</xsl:when>
				<xsl:when test="contains($source,'.ncx')">application/x-dtbncx+xml</xsl:when>
				<xsl:when test="contains($source,'pdf')">pdf</xsl:when>
				<xsl:when test="contains($source,'ppt')">vnd.ms-powerpoint</xsl:when>
				<xsl:when test="contains($source,'eps')">postscript</xsl:when>
				<xsl:when test="contains($source,'ps')">postscript</xsl:when>
				<xsl:when test="contains($source,'rtf')">rtf</xsl:when>
				<xsl:when test="contains($source,'swf')">x-shockwave-flash</xsl:when>
				<xsl:when test="contains($source,'tar')">x-zip-compressed</xsl:when>
				<xsl:when test="contains($source,'wpd')">wordperfect5.1</xsl:when>
				<xsl:when test="contains($source,'xls')">vnd.ms-excel</xsl:when>
				<xsl:when test="contains($source,'zip')">x-zip-compressed</xsl:when>
			</xsl:choose>
	</xsl:template>

	<xsl:template name="audio-subtype">
		<xsl:param name="source"/>
			<xsl:choose>
				<xsl:when test="contains($source,'au')">basic</xsl:when>
				<xsl:when test="contains($source,'midi')">x-midi</xsl:when>
				<xsl:when test="contains($source,'mp3')">mpeg</xsl:when>
				<xsl:when test="contains($source,'ra')">x-realaudio</xsl:when>
				<xsl:when test="contains($source,'wav')">wav</xsl:when>
				</xsl:choose>
		</xsl:template>


	<xsl:template name="video-subtype">
		<xsl:param name="source"/>
			<xsl:choose>
				<xsl:when test="contains($source,'asf')">x-ms-asf</xsl:when>
				<xsl:when test="contains($source,'avi')">x-msvideo</xsl:when>
				<xsl:when test="contains($source,'mov')">quicktime</xsl:when>
				<xsl:when test="contains($source,'mpeg')">mpeg</xsl:when>
				<xsl:when test="contains($source,'mpg')">mpeg</xsl:when>
				<xsl:when test="contains($source,'mp4')">mp4</xsl:when>
				<xsl:when test="contains($source,'rm')">vnd.rn-realmedia</xsl:when>
				<xsl:when test="contains($source,'rv')">vnd.rn-realvideo</xsl:when>
				<xsl:when test="contains($source,'wmv')">x-ms-wmv</xsl:when>
				</xsl:choose>
		</xsl:template>


	<xsl:template name="text-subtype">
		<xsl:param name="source"/>
			<xsl:choose>
				<xsl:when test="contains($source,'.css')">css</xsl:when>
				<xsl:when test="contains($source,'html')">html</xsl:when>
				<xsl:when test="contains($source,'sgml')">sgml</xsl:when>
				<xsl:when test="contains($source,'xml')">xml</xsl:when>
				<xsl:otherwise>plain</xsl:otherwise>
				</xsl:choose>
		</xsl:template>









</xsl:stylesheet>   
