<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet 
	xmlns="http://www.daisy.org/z3986/2005/ncx/"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	version="2.0">
	
	<xsl:output name="ncx" method="xml" indent="yes" 
		doctype-public="-//NISO//DTD ncx 2005-1//EN" 
		doctype-system="http://www.daisy.org/z3986/2005/ncx-2005-1.dtd"/>
	
	
	<xsl:param name="outfile"/>
	
	<xsl:template match="/">
			<ncx xmlns="http://www.daisy.org/z3986/2005/ncx/" version="2005-1">
				<xsl:call-template name="make-ncx-head"/>
				<xsl:call-template name="make-docTitle"/>
				<xsl:call-template name="make-docAuthor"/>
				<xsl:call-template name="make-ncx-navMap"/>
			</ncx>
		<!--</xsl:result-document>-->
	</xsl:template>
	
	<xsl:template name="make-ncx-head">
		<head>
			<meta name="dtb:uid" content="{/article/@dtd-version}"/>
		</head>
	</xsl:template>
	
	
	<xsl:template name="make-docTitle">
		<docTitle>
			<text>
				<xsl:value-of select="/article/front/article-meta/title-group/article-title"/>
			</text>
		</docTitle>
	</xsl:template>
	
	<xsl:template name="make-docAuthor">
		<xsl:for-each select="/article/front/article-meta/contrib-group/contrib">
			<docAuthor>
				<text>
					<xsl:choose>
						<xsl:when test="name">
							<xsl:value-of select="name/given-names, name/surname, name/suffix"/>
						</xsl:when>
						<xsl:when test="collab">
							<xsl:value-of select="collab"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="string(.)"/>
						</xsl:otherwise>
					</xsl:choose>
				</text>
			</docAuthor>
		</xsl:for-each>
	</xsl:template>
	
	
	<xsl:template name="make-ncx-navMap">
		<navMap>
			<xsl:call-template name="nav-points">
				<xsl:with-param name="node" select="/article"/>
				<xsl:with-param name="position" select="1"/>
			</xsl:call-template>
		</navMap>
	</xsl:template>

	<xsl:template name="nav-points">
		<xsl:param name="node"/>
		<xsl:param name="position"/>
		<xsl:if test="$node">
			<navPoint id="navpoint-{$position}" playOrder="{$position}">
				<navLabel>
					<text><xsl:value-of select="$node[1]/front/article-meta/title-group/article-title"/></text>
				</navLabel>
				<content src="{$outfile}"/>
			</navPoint>
			<xsl:call-template name="nav-points">
				<xsl:with-param name="node" select="$node[position() != 1]"/>
				<xsl:with-param name="position" select="$position + 1"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>
